==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/Connectors/action_view_map.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/


$action_view_map['retrievesource']= 'retrievesource';
$action_view_map['step1']= 'step1';
$action_view_map['step2']= 'step2';

//Admin main page
$action_view_map['connectorsettings'] = 'connectorsettings';

//Admin pages for the connector properties
$action_view_map['modifyproperties'] = 'modifyproperties';
$action_view_map['sourceproperties']= 'sourceproperties';

//Admin pages to enable/disable connector for modules
$action_view_map['modifydisplay'] = 'modifydisplay';
$action_view_map['displayproperties'] = 'displayproperties';

//Admin pages to modify search field mapping for connectors
$action_view_map['modifysearch'] = 'modifysearch';
$action_view_map['searchproperties'] = 'searchproperties';

//Admin pages to modify field mapping for the connectors
$action_view_map['modifymapping'] = 'modifymapping';
$action_view_map['mappingproperties'] = 'mappingproperties';
?>

==> SugarCE-6.2.1.zip: SugarCE-Full-6.2.1/modules/Connectors/action_view_map.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/


$action_view_map['retrievesource']= 'retrievesource';
$action_view_map['step1']= 'step1';
$action_view_map['step2']= 'step2';

//Admin main page
$action_view_map['connectorsettings'] = 'connectorsettings';

//Admin pages for the connector properties
$action_view_map['modifyproperties'] = 'modifyproperties';
$action_view_map['sourceproperties']= 'sourceproperties';

//Admin pages to enable/disable connector for modules
$action_view_map['modifydisplay'] = 'modifydisplay';
$action_view_map['displayproperties'] = 'displayproperties';

//Admin pages to modify search field mapping for connectors
$action_view_map['modifysearch'] = 'modifysearch';
$action_view_map['searchproperties'] = 'searchproperties';

//Admin pages to modify field mapping for the connectors
$action_view_map['modifymapping'] = 'modifymapping';
$action_view_map['mappingproperties'] = 'mappingproperties';
?>
